[xiph-commits] r16983 - in trunk/ao/src: . plugins/arts

xiphmont at svn.xiph.org xiphmont at svn.xiph.org
Thu Mar 18 14:10:32 PDT 2010


Author: xiphmont
Date: 2010-03-18 14:10:32 -0700 (Thu, 18 Mar 2010)
New Revision: 16983

Modified:
   trunk/ao/src/audio_out.c
   trunk/ao/src/plugins/arts/ao_arts.c
Log:
Remove some relatively useless aRTs debug messages
Add additional channel mapping debug output.



Modified: trunk/ao/src/audio_out.c
===================================================================
--- trunk/ao/src/plugins/arts/ao_arts.c	2010-03-18 19:50:04 UTC (rev 16982)
+++ trunk/ao/src/plugins/arts/ao_arts.c	2010-03-18 21:10:32 UTC (rev 16983)
@@ -233,8 +233,6 @@
   server_open_count++;
   pthread_mutex_unlock(&mutex);
 
-  adebug("thread %p: playback stream created!\n",internal->stream);
-  adebug("thread %p: buffer size = %d bytes\n",internal->stream,internal->buffersize);
   return 1;
 }
 
@@ -318,13 +316,10 @@
       wait = (wait/8)*1000;
       if(wait<1)wait=1;
       if(wait>500000)wait=500000;
-      adebug("thread %p: wrote %d bytes\n",internal->stream,accwrote);
-      adebug("thread %p: playback stream waiting %dus\n",internal->stream,wait);
       usleep(wait);
       pthread_mutex_lock(&mutex);
     }else{
       pthread_mutex_unlock(&mutex);
-      adebug("thread %p: wrote %d bytes\n",internal->stream,accwrote);
       break;
     }
   }



More information about the commits mailing list
--- trunk/ao/src/audio_out.c	2010-03-18 19:50:04 UTC (rev 16982)
+++ trunk/ao/src/audio_out.c	2010-03-18 21:10:32 UTC (rev 16983)
@@ -1039,7 +1039,7 @@
                  info_table[device->driver_id]->short_name);
           }else{
 
             /* walk thorugh the inter matrix, match channles */
             char *op=device->inter_matrix;
             int count=0;
             device->inter_permute = calloc(device->output_channels,sizeof(int));
@@ -1082,6 +1082,23 @@
               op=h;
               if(*h)op++;
             }
+            {
+              char **inch = _tokenize_matrix(sformat.matrix);
+              int i,j;
+              int unflag=0;
+              for(j=0;j<sformat.channels;j++){
+                for(i=0;i<device->output_channels;i++)
+                  if(device->inter_permute[i]==j)break;
+                if(i==device->output_channels){
+                  averbose("input %d (%s)\t -> none\n",
+                           j,inch[j]);
+                  unflag=1;
+                }
+              }
+              _free_map(inch);
+              if(unflag)
+                awarn("Some input channels are unmapped and will not be used.\n");
+            }
             averbose("\n");
 
           }
@@ -1039,7 +1039,7 @@
           }else{
 
-            /* walk thorugh the inter matrix, match channles */
+            /* walk thorugh the inter matrix, match channels */
             char *op=device->inter_matrix;
             int count=0;

Modified: trunk/ao/src/plugins/arts/ao_arts.c
===================================================================